@@ -51,6 +51,20 @@ JOB_TYPE_SPARK_ON_JOBSERVER = 'spark-on-jobserver'
 PIG__0_12 = "0.12"
 PIG__0_12_HADOOP_2 = "0.12-Hadoop-2"
 
+
+def get_script_name_key(job_type):
+    """
+    internal DRY helper for common API parameter.
+    """
+    if job_type in (JOB_TYPE_SPARK_ON_JOBSERVER, JOB_TYPE_SPARK):
+        return 'sparkclass_name'
+    elif job_type == JOB_TYPE_LUIGI:
+        return 'luigiscript_name'
+    else:
+        # default is to assume pig.
+        return 'pigscript_name'
+
+
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
@@ -118,16 +132,10 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
             'notify_on_job_finish': notify_on_job_finish,
             'use_spot_instances': use_spot_instances,
             'pipeline_job_id': pipeline_job_id,
-            'job_type': job_type
+            'job_type': job_type,
+            get_script_name_key(job_type): script_name
     }
 
-    if is_control_script:
-        body["controlscript_name"] = script_name
-    elif job_type == JOB_TYPE_SPARK_ON_JOBSERVER:
-        body["sparkclass_name"] = script_name
-    else:
-        body["pigscript_name"] = script_name
-
     if pig_version:
         body["pig_version"] = pig_version
 
@@ -178,15 +186,13 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
             'parameters': parameters or {},
             'notify_on_job_finish': notify_on_job_finish,
             'use_spot_instances': use_spot_instances,
-            'job_type': job_type
+            'job_type': job_type,
+            get_script_name_key(job_type): script_name
     }
 
     if pig_version:
         body["pig_version"] = pig_version
 
-    if job_type == JOB_TYPE_SPARK_ON_JOBSERVER:
-        body["sparkclass_name"] = script_name
-
     return api.post('jobs', body)['job_id']
 
 
@@ -238,16 +244,10 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
             'parameters': parameters or {},
             'notify_on_job_finish': notify_on_job_finish,
             'pipeline_job_id': pipeline_job_id,
-            'job_type': job_type
+            'job_type': job_type,
+            get_script_name_key(job_type): script_name
     }
 
-    if is_control_script:
-        body["controlscript_name"] = script_name
-    elif job_type == JOB_TYPE_SPARK_ON_JOBSERVER:
-        body["sparkclass_name"] = script_name
-    else:
-        body["pigscript_name"] = script_name
-
     if pig_version:
         body["pig_version"] = pig_version
 
@@ -285,14 +285,10 @@ def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
             'cluster_id': cluster_id,
             'parameters': parameters or {},
             'notify_on_job_finish': notify_on_job_finish,
-            'job_type': job_type
+            'job_type': job_type,
+            get_script_name_key(job_type): script_name
     }
 
-    if pig_version:
-        body["pig_version"] = pig_version
-    if job_type == JOB_TYPE_SPARK_ON_JOBSERVER:
-        body["sparkclass_name"] = script_name
-
     return api.post('jobs', body)['job_id']
 
 
